package net.wanji.utc.common.constant;

import net.wanji.utc.common.commonentity.HttpRequest;
import net.wanji.utc.common.typeenum.BasicEnum;
import net.wanji.utc.po.ApiInfoPO;
import net.wanji.utc.vo.CrossLanesVo;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

@Component
public class Constants {
    /**
     * 厂商接口地址
     */
    private static ConcurrentHashMap<String, ApiInfoPO> manufacturerUrlMap = new ConcurrentHashMap<>();

    /**
     * 存储海康信号机车道关系到内存
     */
    private static ConcurrentHashMap<String, List<CrossLanesVo>> telesemeLaneRealMap = new ConcurrentHashMap<>();

    /**
     * 系统缩写
     */
    public static final String SYSTEM_ABBR = "UTC";


    /**
     * 分隔符：下划线
     **/
    public static final String SEPARATOR_UNDER_LINE = "_";


    /**
     * 分隔符：逗号
     **/
    public static final String SEPARATOR_COMMA = ",";

    /**
     * 分隔符：减号
     **/
    public static final String SEPARATOR_MINUS = "-";


    /**
     * 分隔符：冒号
     **/
    public static final String SEPARATOR_COLON = ":";

    /**
     * 海康返回成功码
     */
    public static final Integer HK_SUCCESS_CODE = 0;
    /**
     * 海康返回码的 key
     */
    public static final String HK_CODE_KEY = "code";

    /**
     * 失败-false
     */
    public static final int FALSE = 0;
    /**
     * 成功-true
     */
    public static final int TRUE = 1;

    /**
     * 相位（灯态）锁定
     */
    public static final Integer LOCK_RUNNING_CONTROL = 12;
    /**
     * 相位（灯态）解锁: 0-多时段控制模式
     */
    public static final Integer UNLOCK_RUNNING_CONTROL = 13;
    /**
     * 恢复正常方案: 0-多时段控制模式
     */
    public static final Integer NORMAL_RUNNING_CONTROL = 0;
    /**
     * 关灯
     */
    public static final Integer CLOSE_LIGHT_CONTROL = 1;
    /**
     * 黄闪
     */
    public static final Integer YELLOW_LIGHT_CONTROL = 2;
    /**
     * 手动全红
     */
    public static final Integer ALL_RED_CONTROL = 3;
    /**
     * 定周期控制
     */
    public static final Integer FIXED_CYCLE_MODE = 4;
    /**
     * 步进控制
     */
    public static final Integer STEP_CONTROL = 10;
    /**
     * 取消步进
     */
    public static final Integer CANCEL_STEP_CONTROL = 11;

    public static ApiInfoPO getManufacturerUrlMap(String key) {
        return manufacturerUrlMap.get(key);
    }

    public static void putManufacturerUrlMap(String key, ApiInfoPO value) {
        manufacturerUrlMap.put(key, value);
    }


    public static void setTelesemeLaneRealMap(ConcurrentHashMap<String, List<CrossLanesVo>> telesemeLaneRealMap) {
        Constants.telesemeLaneRealMap = telesemeLaneRealMap;
    }

    private static String artemisPath;

    @Value("${signal.manufacturer.hk.artemisPath}")
    public static void setArtemisPath(String artemisPath) {
        Constants.artemisPath = artemisPath;
    }

    /**
     * 根据code获取三方 url
     */
    public static Map<String, String> getPathMapByApiCode(String apiCode) {
        Map<String, String> res = new HashMap<>();
        HttpRequest httpRequest = new HttpRequest(BasicEnum.ManufacturerEnum.HK.getAbbr(), apiCode);
        res.put("http://", artemisPath + httpRequest.getUrl());
        return res;
    }

    public static ConcurrentHashMap<String, List<CrossLanesVo>> getTelesemeLaneRealMap() {
        return telesemeLaneRealMap;
    }
}